public inbox for linux-kernel@vger.kernel.org
 help / color / mirror / Atom feed
* RE: [openib-general] Re: [PATCH 21 of 53] ipath - use phys_to_virt instead of bus_to_virt
@ 2006-05-15 23:40 Caitlin Bestler
  2006-05-15 23:50 ` Roland Dreier
  0 siblings, 1 reply; 6+ messages in thread
From: Caitlin Bestler @ 2006-05-15 23:40 UTC (permalink / raw)
  To: Roland Dreier, Grant Grundler
  Cc: openib-general, linux-kernel, Segher Boessenkool

openib-general-bounces@openib.org wrote:
>     Grant> Aren't remote addresses handled differently than local
>     Grant> ones?  ULP has to map local addresses.  We can't map remote
>     Grant> ones (remote host maps it).  The ULP must know the
>     Grant> difference and can tell the lower level driver which is   
> Grant> which. 
> 
> The problem is that RDMA requests have to be handled by the
> low-level driver (or hardware) without any ULP involvement.
> So every device has to handle getting messages like "send me
> XXX bytes of data from address YYY in the memory region
> corresponding to R_Key ZZZ."
> 

True, but how does that constrain the local interfaces by which
the driver is informed of the set of pages that back a given
memory region? The driver must still ultimately provide dma
accessible addresses to the device. RDMA just changes the
timing of the steps, albeit radically, but not what the
steps are.


^ permalink raw reply	[flat|nested] 6+ messages in thread
* [PATCH 21 of 53] ipath - use phys_to_virt instead of bus_to_virt
@ 2006-05-12 23:43 Bryan O'Sullivan
  2006-05-15 15:50 ` Roland Dreier
  0 siblings, 1 reply; 6+ messages in thread
From: Bryan O'Sullivan @ 2006-05-12 23:43 UTC (permalink / raw)
  To: rdreier; +Cc: openib-general, linux-kernel

I think Roland already has this patch.

diff -r 201654fe1962 -r 4e0a07d20868 drivers/infiniband/hw/ipath/ipath_keys.c
--- a/drivers/infiniband/hw/ipath/ipath_keys.c	Fri May 12 15:55:28 2006 -0700
+++ b/drivers/infiniband/hw/ipath/ipath_keys.c	Fri May 12 15:55:28 2006 -0700
@@ -126,11 +126,11 @@ int ipath_lkey_ok(struct ipath_lkey_tabl
 	/*
 	 * We use LKEY == zero to mean a physical kmalloc() address.
 	 * This is a bit of a hack since we rely on dma_map_single()
 	 * being reversible by calling bus_to_virt().
 	 */
 	if (sge->lkey == 0) {
 		isge->mr = NULL;
-		isge->vaddr = bus_to_virt(sge->addr);
+		isge->vaddr = phys_to_virt(sge->addr);
 		isge->length = sge->length;
 		isge->sge_length = sge->length;
 		ret = 1;

^ permalink raw reply	[flat|nested] 6+ messages in thread

end of thread, other threads:[~2006-05-15 23:50 UTC | newest]

Thread overview: 6+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2006-05-15 23:40 [openib-general] Re: [PATCH 21 of 53] ipath - use phys_to_virt instead of bus_to_virt Caitlin Bestler
2006-05-15 23:50 ` Roland Dreier
  -- strict thread matches above, loose matches on Subject: below --
@@ -126,11 +126,11 @@ int ipath_lkey_ok(struct ipath_lkey_tabl
 	 * We use LKEY == zero to mean a physical kmalloc() address.
 	 * This is a bit of a hack since we rely on dma_map_single()
-	 * being reversible by calling bus_to_virt().
+	 * being reversible by calling phys_to_virt().
 	 */
 	if (sge->lkey == 0) {
2006-05-12 23:43 Bryan O'Sullivan
2006-05-15 15:50 ` Roland Dreier
2006-05-15 21:21   ` Bryan O'Sullivan
2006-05-15 21:28     ` Roland Dreier
2006-05-15 23:13       ` [openib-general] " Grant Grundler
2006-05-15 23:16         ` Roland Dreier
2006-05-15 23:30           ` Grant Grundler
2006-05-15 23:34             ` Roland Dreier

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox